diff --git a/plinth/modules/minetest/manifest.py b/plinth/modules/minetest/manifest.py
index 3963d7ce2..27c65380d 100644
--- a/plinth/modules/minetest/manifest.py
+++ b/plinth/modules/minetest/manifest.py
@@ -6,19 +6,19 @@ from plinth.clients import store_url
clients = [{
'name':
- _('Minetest'),
+ _('Luanti'),
'platforms': [{
'type': 'download',
'os': 'gnu-linux',
- 'url': 'https://www.minetest.net/downloads/'
+ 'url': 'https://www.luanti.org/downloads/'
}, {
'type': 'download',
'os': 'macos',
- 'url': 'https://www.minetest.net/downloads/'
+ 'url': 'https://www.luanti.org/downloads/'
}, {
'type': 'download',
'os': 'windows',
- 'url': 'https://www.minetest.net/downloads/'
+ 'url': 'https://www.luanti.org/downloads/'
}, {
'type': 'store',
'os': 'android',
@@ -32,7 +32,7 @@ clients = [{
}, {
'type': 'package',
'format': 'deb',
- 'name': 'minetest'
+ 'name': 'luanti'
}]
}]
diff --git a/plinth/modules/minetest/urls.py b/plinth/modules/minetest/urls.py
index 1e057eee2..9f5f166cb 100644
--- a/plinth/modules/minetest/urls.py
+++ b/plinth/modules/minetest/urls.py
@@ -8,5 +8,6 @@ from django.urls import re_path
from plinth.modules.minetest.views import MinetestAppView
urlpatterns = [
- re_path(r'^apps/minetest/$', MinetestAppView.as_view(), name='index'),
+ re_path(r'^apps/minetest/$', MinetestAppView.as_view(), name='index-old'),
+ re_path(r'^apps/luanti/$', MinetestAppView.as_view(), name='index'),
]
diff --git a/plinth/modules/minetest/__init__.py b/plinth/modules/minetest/__init__.py
index c4924d74a..4a5bb33a4 100644
--- a/plinth/modules/minetest/__init__.py
+++ b/plinth/modules/minetest/__init__.py
@@ -1,5 +1,5 @@
# SPDX-License-Identifier: AGPL-3.0-or-later
"""FreedomBox app for Minetest server."""
import augeas
from django.urls import reverse_lazy
@@ -30,10 +30,11 @@ _mods = [
_description = [
format_lazy(
- _('Minetest is a multiplayer infinite-world block sandbox. This '
- 'module enables the Minetest server to be run on this '
- '{box_name}, on the default port (30000). To connect to the server, '
- 'a Minetest client '
+ _('Luanti, formally known as Minetest, is a multiplayer '
+ 'infinite-world block sandbox. This module enables the Luanti '
+ 'server to be run on this {box_name}, on the default port (30000). '
+ 'To connect to the server, a '
+ 'Luanti client '
'is needed.'), box_name=_(cfg.box_name)),
]
@@ -42,7 +43,7 @@ AUG_PATH = '/files' + CONFIG_FILE + '/.anon'
class MinetestApp(app_module.App):
"""FreedomBox app for Minetest."""
app_id = 'minetest'
@@ -53,11 +54,11 @@ class MinetestApp(app_module.App):
super().__init__()
info = app_module.Info(
- app_id=self.app_id, version=self._version, name=_('Minetest'),
+ app_id=self.app_id, version=self._version, name=_('Luanti'),
icon_filename='minetest', description=_description,
manual_page='Minetest', clients=manifest.clients,
tags=manifest.tags,
- donation_url='https://www.minetest.net/get-involved/#donate')
+ donation_url='https://www.luanti.org/donate/')
self.add(info)
menu_item = menu.Menu('menu-minetest', info.name, info.icon_filename,
@@ -1,5 +1,5 @@
# SPDX-License-Identifier: AGPL-3.0-or-later
-"""FreedomBox app for Minetest server."""
+"""FreedomBox app for Luanti (formally Minetest) server."""
import augeas
from django.urls import reverse_lazy
@@ -42,7 +43,7 @@ AUG_PATH = '/files' + CONFIG_FILE + '/.anon'
class MinetestApp(app_module.App):
- """FreedomBox app for Minetest."""
+ """FreedomBox app for Luanti (formally Minetest)."""
app_id = 'minetest'